===================
Text Representation
===================

Text representation commands are used to determine how objects are printed on the Python command line.

Classes
-------

redentABQ
~~~~~~~~~

.. automodule:: abaqus.TextRepresentation.redentABQ
    :members:
    :special-members: __init__

textRepr
~~~~~~~~

.. automodule:: abaqus.TextRepresentation.textRepr
    :members:
    :special-members: __init__

TextReprOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.TextRepresentation.TextReprOptions.TextReprOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

